FormatFn

Type Alias FormatFn 

pub type FormatFn = unsafe fn(payload: *const u8, out: &mut FormatSink<'_>);
format callback shape: append the user-visible representation of the value to the given writer, in that writer’s FormatStyle.

Safety

payload must point at a value of the descriptor’s type.